==> bejesus-cli-0.0.1.tgz: package/api/bejesus.js <==
var request = require('request');
var querystring = require('querystring');
var fs = require('fs');
var sys = require('sys');

var headers = {'Content-Type': 'application/x-www-form-urlencoded'};
var bejesus = function (username, password, basehost) {
  if (typeof baseurl != 'undefined') this.basehost = basehost;
  else this.basehost = 'api.bejes.us';
  this.username = username;
  this.password = password;
  if (this.username.length > 0 && this.password.length > 0) {
    var userbits = this.username + ":" + this.password + "@";
  } else {
    var userbits = "";
  }
  this.baseurl = "http://" + userbits + this.basehost + "/";
};

bejesus.prototype.coupon_request = function (email, cb) {
  request({uri: this.baseurl + "coupon", method: "POST", body: querystring.stringify({email: email}), headers: headers}, function (err, resp, body) {
      cb(JSON.parse(body));
    }
  );
};

bejesus.prototype.user_create = function (user, pass, email, rsakey, coupon, cb) {
  request({
    uri: this.baseurl + "user",
    method: 'POST',
    body: querystring.stringify({
      user: user,
      password: pass,
      email: email,
      coupon: coupon,
      rsakey: fs.readFileSync(rsakey)
    }),
    headers: headers
    },
    function (err, resp, body) {
      cb(JSON.parse(body))
    }
  );
};

bejesus.prototype.apps_list = function (cb) {
  request({uri: this.baseurl + "apps", method: 'GET'}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.app_create = function (name, start, cb) {
  request({uri: this.baseurl + "app", method: 'POST', body: querystring.stringify({appname: name, start: start}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

/*
bejesus.prototype.app_set_start = function (name, start, cb) {
  
};
*/

bejesus.prototype.app_running = function (name, running, cb) {
  request({uri: this.baseurl + "app", method: 'PUT', body: querystring.stringify({appname: name, running: running}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.app_start = function (name, cb) {
  this.app_running(name, "true", cb);
};

bejesus.prototype.app_restart = function (name, cb) {
  this.app_running(name, "restart", cb);
};

bejesus.prototype.app_stop = function (name, cb) {
  this.app_running(name, "false", cb);
};

bejesus.prototype.app_delete = function (name, cb) {
  
};

bejesus.prototype.app_info = function (name, cb) {
  request({uri: this.baseurl + "app/" + name, method: 'GET', headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.appnpm_handler = function (name, package, action, cb) {
  request({uri: this.baseurl + "appnpm", method: 'POST', headers: headers, body: querystring.stringify({appname: name, package: package, action: action})}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.appnpm_install = function (name, package, cb) {
  this.appnpm_handler(name, package, "install", cb);
};

bejesus.prototype.appnpm_update = function (name, package, cb) {
  this.appnpm_handler(name, package, "update", cb);
};

bejesus.prototype.appnpm_uninstall = function (name, package, cb) {
  this.appnpm_handler(name, package, "uninstall", cb);
};

exports.bejesus = bejesus;

==> bejesus-cli-0.1.5.tgz: package/api/bejesus.js <==
var request = require('request');
var querystring = require('querystring');
var fs = require('fs');
var sys = require('sys');

var headers = {'Content-Type': 'application/x-www-form-urlencoded'};
var bejesus = function (username, password, basehost) {
  if (typeof baseurl != 'undefined') this.basehost = basehost;
  else this.basehost = 'api.bejes.us';
  this.username = username;
  this.password = password;
  if (typeof this.username != 'undefined' && typeof this.password != 'undefined' && this.username.length > 0 && this.password.length > 0) {
    var userbits = this.username + ":" + this.password + "@";
  } else {
    var userbits = "";
  }
  this.baseurl = "http://" + userbits + this.basehost + "/";
};

bejesus.prototype.coupon_request = function (email, cb) {
  request({uri: this.baseurl + "coupon", method: "POST", body: querystring.stringify({email: email}), headers: headers}, function (err, resp, body) {
      cb(JSON.parse(body));
    }
  );
};

bejesus.prototype.user_create = function (user, pass, email, rsakey, coupon, cb) {
  var rsadata = fs.readFileSync(rsakey).toString();
  if (rsadata.length < 40) {
    cb("Error: Invalid SSH key file.");
  } else {
    request({
      uri: this.baseurl + "user",
      method: 'POST',
      body: querystring.stringify({
        user: user,
        password: pass,
        email: email,
        coupon: coupon,
        rsakey: rsadata
      }),
      headers: headers
      },
      function (err, resp, body) {
        cb(JSON.parse(body))
      }
    );
  }
};

bejesus.prototype.user_setpass = function (newpass, cb) {
  request({uri: this.baseurl + "user", method: 'PUT', body: querystring.stringify({password: newpass}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.user_setkey = function (rsakey, cb) {
  request({uri: this.baseurl + "user", method: 'PUT', body: querystring.stringify({rsakey: rsakey}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.apps_list = function (cb) {
  request({uri: this.baseurl + "apps", method: 'GET'}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.app_create = function (name, start, cb) {
  request({uri: this.baseurl + "app", method: 'POST', body: querystring.stringify({appname: name, start: start}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

/*
bejesus.prototype.app_set_start = function (name, start, cb) {
  
};
*/

bejesus.prototype.app_running = function (name, running, cb) {
  request({uri: this.baseurl + "app", method: 'PUT', body: querystring.stringify({appname: name, running: running}), headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.app_start = function (name, cb) {
  this.app_running(name, "true", cb);
};

bejesus.prototype.app_restart = function (name, cb) {
  this.app_running(name, "restart", cb);
};

bejesus.prototype.app_stop = function (name, cb) {
  this.app_running(name, "false", cb);
};

bejesus.prototype.app_delete = function (name, cb) {
  
};

bejesus.prototype.app_info = function (name, cb) {
  request({uri: this.baseurl + "app/" + name, method: 'GET', headers: headers}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.appnpm_handler = function (name, package, action, cb) {
  request({uri: this.baseurl + "appnpm", method: 'POST', headers: headers, body: querystring.stringify({appname: name, package: package, action: action})}, function (err, response, body) {
    cb(JSON.parse(body));
  });
};

bejesus.prototype.appnpm_install = function (name, package, cb) {
  this.appnpm_handler(name, package, "install", cb);
};

bejesus.prototype.appnpm_update = function (name, package, cb) {
  this.appnpm_handler(name, package, "update", cb);
};

bejesus.prototype.appnpm_uninstall = function (name, package, cb) {
  this.appnpm_handler(name, package, "uninstall", cb);
};

exports.bejesus = bejesus;
